MessageProvider<T extends MessageEnum> class abstract

Abstract provider to be implemented by the application. Acts as the source for intl translation extraction.

Constructors

MessageProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(T message, {Map<String, Object>? args}) String
Resolves the message to its localized string. Implementations should use Intl.message to define the translation key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited